##  Linking an Application Fact Sheet from the Fact Sheet Page
Follow these steps:
  1. Open an application fact sheet.
  2. On the right-side panel, under Reference Catalog, click Start Linking. The catalog page opens with relevant recommendations for that fact sheet.
  3. Choose the catalog item to link or search for a specific item to link from the search bar, then click Link.


![Linking Applications From the Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c1acf7a441014be5cb13aaf1da824_LowRes.png)
Linking a Fact Sheet to a Catalog Item from the Fact Sheet Page
